@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, url
 from django_summernote.views import editor, upload_attachment
 
 urlpatterns = patterns(
